#!/usr/bin/sed -f
#
# utf8..latin1.sed
#
# Translate UTF8 characters to latin1 that GNU recode is unable to handle.
#
# This sed script belongs to utf8..latin1 (but also works on its own).
#
# Copyright (C) by Volker Kuhlmann
#               http://volker.top.geek.nz/contact.html
# All rights reserved.
# Released under the terms of the GNU General Public License (GPL) Version 2.
# See http://www.gnu.org/ for details.
#
# Volker Kuhlmann
#   1.0, 08 Jun 2013
#   1.1, 26 Jun 2013  Handle UTF-8 spaces.
#   1.1.2, 17 Oct 2013  Added U+03C0, U+2248.
#

#(Note: can't use latin1 characters in here because they are mutually
# exclusive with UTF8 ones in the same file.)

# Line/paragraph separator: see
# http://www.unicode.org/reports/tr13/tr13-9.html

# sed command			# code point	UTF8	# ASC	UTF8 hex codes
#				#			#(appr)

# Spaces
s/\xe2\x80\x80/ /g		# U+2000 en		# SP	e2 80 80
s/\xe2\x80\x81/ /g		# U+2001 em		# SP	e2 80 81
s/\xe2\x80\x82/ /g		# U+2002 en		# SP	e2 80 82
s/\xe2\x80\x83/ /g		# U+2003 em		# SP	e2 80 83
s/\xe2\x80\x84/ /g		# U+2004 thick		# SP	e2 80 84
s/\xe2\x80\x85/ /g		# U+2005 mid		# SP	e2 80 85
s/\xe2\x80\x86/ /g		# U+2006 (thin)		# SP	e2 80 86
s/\xe2\x80\x87/ /g		# U+2007 figure		# SP	e2 80 87
s/\xe2\x80\x88/ /g		# U+2008 punct.		# SP	e2 80 88
s/\xe2\x80\x89/ /g		# U+2009 thin		# SP	e2 80 89
s/\xe2\x80\x8a/ /g		# U+200A hair		# SP	e2 80 8a
s/\xe2\x80\x8b//g		# U+200B ZWSP		# 	e2 80 8b

# Format characters
s/\xe2\x80\xa8/\x0a/g		# U+2028 (LS)		# NL	e2 80 a8
s/\xe2\x80\xa9/\x0a\x0a/g	# U+2029 (PS)		# 	e2 80 a9

# Mathematics
s/\xcf\x80/pi/g			# U+03C0	π	# pi	cf 80
s/\xe2\x89\x88/appr/g		# U+2248	≈	# appr	e2 89 88
